---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run tool '...'
2. With arguments '...'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots/Logs**
If applicable, add screenshots or logs to help explain your problem.

**Environment (please complete the following information):**
 - OS: [e.g. macOS, Linux]
 - Python Version: [e.g. 3.10]
 - Peircean Version: [e.g. 0.2.0]

**Additional context**
Add any other context about the problem here.
